@@ -7,6 +7,7 @@ from typing import IO, ClassVar, cast
 import click
 
 from lockfile_diff.base import InputSchema
+from lockfile_diff.errors import FAILED_TO_PARSE_FILE
 from lockfile_diff.registries import Registries
 from lockfile_diff.types import ParsedData
 from lockfile_diff.util.io.rewind import capture
@@ -32,8 +33,11 @@ class AutoDetectSchema(InputSchema):
             sys.exit(0)
 
         click.echo(
-            f"ERROR: `auto-detect` failed to parse {getattr(source, 'name', str(source))!r} with "
-            "any of the following schemas:"
+            (
+                f"ERROR: `auto-detect` failed to parse {getattr(source, 'name', str(source))!r} with "
+                "any of the following schemas:"
+            ),
+            err=True,
         )
-        click.echo("\n".join(errors))
-        sys.exit(1)
+        click.echo("\n".join(errors), err=True)
+        sys.exit(FAILED_TO_PARSE_FILE)
